==> react-form-builder-5.4.0.tgz: package/lib/Range/Default/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["children"];
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../../prop-types/index.js';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var joinInputValues = function joinInputValues(inputValues) {
  if (inputValues === void 0) {
    inputValues = {};
  }

  var _inputValues = inputValues,
      from = _inputValues.from,
      to = _inputValues.to;
  return [from, to].join(',');
};

var splitInputValues = function splitInputValues(inputValues) {
  var _ref = (inputValues == null ? void 0 : inputValues.split(',')) || [],
      from = _ref[0],
      to = _ref[1];

  return _extends({}, from && {
    from: from
  }, to && {
    to: to
  });
};

var DefaultRange = function DefaultRange(_ref2) {
  var range = _ref2.range,
      tabIndex = _ref2.tabIndex,
      onChange = _ref2.onChange,
      onFocus = _ref2.onFocus,
      onBlur = _ref2.onBlur,
      errors = _ref2.errors,
      alerts = _ref2.alerts,
      renderer = _ref2.renderer;
  var fromInputId = range.id + "-from";
  var toInputId = range.id + "-to";
  var inputValues = splitInputValues(range.value);

  var onChangeCallback = function onChangeCallback(ev, _ref3) {
    var _extends2;

    var value = _ref3.value,
        name = _ref3.name;
    var inputId = name == null ? void 0 : name.split('-')[1];
    var nextValue = inputId ? joinInputValues(_extends({}, inputValues, (_extends2 = {}, _extends2["" + inputId] = value, _extends2))) : value;
    onChange(range.id, nextValue);
  };

  var onBlurCallback = function onBlurCallback(ev) {
    return onBlur(ev.target.id);
  };

  var onFocusCallback = function onFocusCallback(ev) {
    return onFocus(ev.target.id);
  };

  var rangeProps = _extends({
    id: range.id,
    display: range.display,
    value: range.value,
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback
  }, range.disabled && {
    disabled: true
  }, range.hidden && {
    hidden: true
  });

  var fromInputProps = {
    id: fromInputId,
    name: fromInputId,
    label: range.label || '',
    placeholder: 'Desde',
    type: 'number',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    helpText: range.help,
    tabIndex: tabIndex
  };
  var toInputProps = {
    id: toInputId,
    name: toInputId,
    placeholder: 'Hasta',
    type: 'number',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    helpText: range.help,
    tabIndex: tabIndex
  };

  if (rangeProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: rangeProps.id,
    innerProps: rangeProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  var children = rendererResponse.children,
      rendererProps = _objectWithoutPropertiesLoose(rendererResponse, _excluded);

  var _ref4 = rendererProps.value ? splitInputValues(rendererProps.value) : inputValues,
      fromValue = _ref4.from,
      toValue = _ref4.to;

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-DefaultRange sui-FormBuilder-" + rangeProps.id,
    children: [/*#__PURE__*/_jsxs("div", {
      className: "sui-FormBuilder-DefaultRange-inputs",
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-FormBuilder-Input sui-FormBuilder-DefaultRange-from",
        children: /*#__PURE__*/_jsx(MoleculeInputField, _extends({}, fromInputProps, rendererProps, {
          value: fromValue
        }))
      }), /*#__PURE__*/_jsx("div", {
        className: "sui-FormBuilder-Input sui-FormBuilder-DefaultRange-to",
        children: /*#__PURE__*/_jsx(MoleculeInputField, _extends({}, toInputProps, rendererProps, {
          value: toValue
        }))
      })]
    }), children]
  });
};

DefaultRange.displayName = 'DefaultRange';
export default /*#__PURE__*/memo(DefaultRange, createComponentMemo('range'));

==> react-form-builder-5.9.0.tgz: package/lib/Range/Default/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["children"];
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { createComponentMemo, field } from '../../prop-types/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var joinInputValues = function joinInputValues(inputValues) {
  if (inputValues === void 0) {
    inputValues = {};
  }

  var _inputValues = inputValues,
      from = _inputValues.from,
      to = _inputValues.to;
  return [from, to].join(',');
};

var splitInputValues = function splitInputValues(inputValues) {
  var _ref = (inputValues == null ? void 0 : inputValues.split(',')) || [],
      from = _ref[0],
      to = _ref[1];

  return _extends({}, from && {
    from: from
  }, to && {
    to: to
  });
};

var DefaultRange = function DefaultRange(_ref2) {
  var range = _ref2.range,
      tabIndex = _ref2.tabIndex,
      onChange = _ref2.onChange,
      onFocus = _ref2.onFocus,
      onBlur = _ref2.onBlur,
      errors = _ref2.errors,
      alerts = _ref2.alerts,
      renderer = _ref2.renderer;
  var fromInputId = range.id + "-from";
  var toInputId = range.id + "-to";
  var inputValues = splitInputValues(range.value);

  var onChangeCallback = function onChangeCallback(ev, _ref3) {
    var _extends2;

    var value = _ref3.value,
        name = _ref3.name;
    var inputId = name == null ? void 0 : name.split('-')[1];
    var nextValue = inputId ? joinInputValues(_extends({}, inputValues, (_extends2 = {}, _extends2["" + inputId] = value, _extends2))) : value;
    onChange(range.id, nextValue);
  };

  var onBlurCallback = function onBlurCallback(ev) {
    return onBlur(ev.target.id);
  };

  var onFocusCallback = function onFocusCallback(ev) {
    return onFocus(ev.target.id);
  };

  var rangeProps = _extends({
    id: range.id,
    display: range.display,
    value: range.value,
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback
  }, range.disabled && {
    disabled: true
  }, range.hidden && {
    hidden: true
  });

  var fromInputProps = {
    id: fromInputId,
    name: fromInputId,
    label: range.label || '',
    placeholder: 'Desde',
    type: 'number',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    helpText: range.help,
    tabIndex: tabIndex
  };
  var toInputProps = {
    id: toInputId,
    name: toInputId,
    placeholder: 'Hasta',
    type: 'number',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    helpText: range.help,
    tabIndex: tabIndex
  };

  if (rangeProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: rangeProps.id,
    innerProps: rangeProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  var children = rendererResponse.children,
      rendererProps = _objectWithoutPropertiesLoose(rendererResponse, _excluded);

  var _ref4 = rendererProps.value ? splitInputValues(rendererProps.value) : inputValues,
      _ref4$from = _ref4.from,
      fromValue = _ref4$from === void 0 ? '' : _ref4$from,
      _ref4$to = _ref4.to,
      toValue = _ref4$to === void 0 ? '' : _ref4$to;

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-DefaultRange sui-FormBuilder-" + rangeProps.id,
    children: [/*#__PURE__*/_jsxs("div", {
      className: "sui-FormBuilder-DefaultRange-inputs",
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-FormBuilder-Input sui-FormBuilder-DefaultRange-from",
        children: /*#__PURE__*/_jsx(MoleculeInputField, _extends({}, fromInputProps, rendererProps, {
          value: fromValue
        }))
      }), /*#__PURE__*/_jsx("div", {
        className: "sui-FormBuilder-Input sui-FormBuilder-DefaultRange-to",
        children: /*#__PURE__*/_jsx(MoleculeInputField, _extends({}, toInputProps, rendererProps, {
          value: toValue
        }))
      })]
    }), children]
  });
};

DefaultRange.displayName = 'DefaultRange';
export default /*#__PURE__*/memo(DefaultRange, createComponentMemo('range'));
